"""
AgentsAegis Security Training - Safe trap package.
This package contains no functionality. It exists as part of
AgentsAegis security awareness training infrastructure.
Learn more: https://agentsaegis.com
"""
